@@ -1,6 +1,14 @@
 "error.bars" <-
-function (x,stats=NULL,ylab ="Dependent Variable",xlab="Independent Variable",main=NULL,eyes=TRUE,ylim= NULL,xlim=NULL, alpha=.05, sd=FALSE, labels=NULL,pos=NULL,arrow.len=.05,arrow.col="black",add=FALSE,bars=FALSE,within=FALSE,col="blue",density=-10,...)  # x   data frame with 
+function (x,stats=NULL,data=NULL,group=NULL,ylab ="Dependent Variable",xlab="Independent Variable",main=NULL,eyes=TRUE,ylim= NULL,xlim=NULL, alpha=.05, sd=FALSE, labels=NULL,pos=NULL,arrow.len=.05,arrow.col="black",add=FALSE,bars=FALSE,within=FALSE,col="blue",density=-10,...)  # x   data frame with 
     {
+     if(!missing(x) && (class(x) == "formula")) {if(!is.null(data))
+   # cat("\nFormula input detected, calling error.bars.by")
+     error.bars.by(x,data=data,x.cat=TRUE,ylab =NULL,xlab=NULL,main=NULL,ylim= ylim, eyes=eyes,alpha=.05,sd=sd,labels=labels, v.labels=NULL, pos=pos, 
+arrow.len=arrow.len,add=add,bars=bars,within=within,colors=col, 
+ legend=0,density=density,...)
+     } else {if(!missing(group)) {  error.bars.by(x,group=group,x.cat=TRUE,ylab =NULL,xlab=NULL,main=NULL,ylim= ylim, eyes=eyes,alpha=.05,sd=sd,labels=labels, v.labels=NULL, pos=pos, 
+arrow.len=arrow.len,add=add,bars=bars,within=within,colors=col, 
+ legend=0,density=density,...)}  else {
     SCALE=.5   #scale the width of the cats eyes
     if(is.null(stats)) {
     	x.stats <- describe(x)
@@ -67,6 +75,9 @@ function (x,stats=NULL,ylab ="Dependent Variable",xlab="Independent Variable",ma
     	  }
     	    }
    }
+   }
+ }  
+   
    #corrected July 25, 2009 to fix bug reported by Junqian Gordon Xu and then modified to be cleaner code
  
    #modified Sept 5, 2009 to handle data with all missing values (why we would want to that is a mystery, but was requested by Junqian Gordon Xu.)
