@@ -9,7 +9,7 @@ function (x,var=NULL, se=NULL, group=NULL,sd=FALSE, effect=NULL, head = 12, tail
    min.n = NULL,max.labels =40, labels = NULL, groups = NULL, gdata = NULL, cex = par("cex"), 
     pt.cex = cex, pch = 21, gpch = 21, bg = par("bg"), color = par("fg"), 
     gcolor = par("fg"), lcolor = "gray", 
-    xlab = NULL, ylab = NULL,xlim=NULL, ...) 
+    xlab = NULL, ylab = NULL,xlim=NULL,add=FALSE, ...) 
 {
     opar <- par("mai", "mar", "cex", "yaxs")
     on.exit(par(opar))
@@ -29,7 +29,7 @@ function (x,var=NULL, se=NULL, group=NULL,sd=FALSE, effect=NULL, head = 12, tail
                                               x <- x$mean[,var]
                                               if(!is.null(effect)) {   #convert means to effect sizes compared to a particular group
                                               x <- ( x$mean[,var]  -x$mean[effect,var])/x$sd[effect,var]
-                                              browser()
+                                            
                                               }
                                               if(sd) {se <- x$sd[,var] } else {se <- se/sqrt(n.obs)}
                                               x <- subset(x,n.obs > min.n)
@@ -59,11 +59,15 @@ function (x,var=NULL, se=NULL, group=NULL,sd=FALSE, effect=NULL, head = 12, tail
         )
       } #end switch
       } else {
-      if(is.null(group)) {
+      if(is.null(group)) {  #the case of just one observation per condition
+      if(is.null(dim(x))) {se <- rep(0,length(x))
+         des <- x
+         labels=NULL } else {
        des <-   describe(x)
          x <-des$mean
         if(sd) { se <- des$sd} else {se <- des$se}
-         names(x) <- rownames(des)} else {
+        
+         names(x) <- rownames(des)}} else {
           if(is.null(xlab)) xlab <- var 
          des <- describeBy(x,group=group)
          x <- se <-  rep(NA,length(des))
@@ -139,7 +143,7 @@ function (x,var=NULL, se=NULL, group=NULL,sd=FALSE, effect=NULL, head = 12, tail
             x <- as.numeric(x)
         }
     }
-    plot.new()
+   if(!add) plot.new()
     linch <- if (!is.null(labels)) 
         max(strwidth(labels, "inch"), na.rm = TRUE)
     else 0
@@ -178,7 +182,7 @@ function (x,var=NULL, se=NULL, group=NULL,sd=FALSE, effect=NULL, head = 12, tail
         linch <- max(strwidth(labels, "inch"), na.rm = TRUE)
         loffset <- (linch + 0.1)/lheight
         labs <- labels[o]
-        mtext(labs, side = 2, line = loffset, at = y, adj = 0, 
+       mtext(labs, side = 2, line = loffset, at = y, adj = 0, 
             col = color, las = 2, cex = cex, ...)
     }
     abline(h = y, lty = "dotted", col = lcolor)
@@ -202,14 +206,14 @@ function (x,var=NULL, se=NULL, group=NULL,sd=FALSE, effect=NULL, head = 12, tail
     }
    if(eyes) {
    for (e in 1:(min(head+tail,n.var))) {catseye(x[e],y[e],ci[e]/qnorm(1-alpha/2),alpha=alpha,density=density) }}
-    axis(1)
-    box()
+  if(!add)  axis(1)
+  if(!add)  box()
     title(main = main, xlab = xlab, ylab = ylab, ...)
    
     
     if(!is.null(des)) { 
      invisible(des)}
-    
+    #report the order if sort 
 }
 
 
