@@ -4,7 +4,7 @@ setCor(y=y,x=x,data=data,z=z,n.obs=n.obs,use=use,std=std,square=square,main=main
 
 
 "setCor" <-
-function(y,x,data,z=NULL,n.obs=NULL,use="pairwise",std=TRUE,square=FALSE,main="Regression Models",plot=TRUE,show=FALSE,zero=TRUE)  {
+function(y,x,data,z=NULL,n.obs=NULL,use="pairwise",std=TRUE,square=FALSE,main="Regression Models",plot=TRUE,show=FALSE,zero=TRUE,alpha=.05)  {
 
  #a function to extract subsets of variables (a and b) from a correlation matrix m or data set m
   #and find the multiple correlation beta weights + R2 of the a set predicting the b set
@@ -16,6 +16,7 @@ function(y,x,data,z=NULL,n.obs=NULL,use="pairwise",std=TRUE,square=FALSE,main="R
   #modified December, 2014  to allow for covariances as well as to fix a bug with single x variable
   #modified April, 2015 to handle data with non-numeric values in the data, which are not part of the analysis
   #Modified November, 2107 to handle "lm" style input using my parse function.
+  #modified July 4, 2018 to add intercepts and confidence intervals (requested by Franz Strich)
   
    cl <- match.call()
     #convert names to locations 
@@ -57,12 +58,13 @@ function(y,x,data,z=NULL,n.obs=NULL,use="pairwise",std=TRUE,square=FALSE,main="R
                     }
 
                     }
+                    means <- colMeans(data,na.rm=TRUE)   #use these later to find the intercept
                     C <- cov(data,use=use)
                     if(std) {m <- cov2cor(C)
                              C <- m} else {m <- C}
                     raw <- TRUE
                    # n.obs=dim(data)[1]   #this does not take into account missing data
-                    n.obs <- max(count.pairwise(data),na.rm=TRUE )  #this does
+                    n.obs <- max(pairwiseCount(data),na.rm=TRUE )  #this does
                     }  else {
                     raw <- FALSE
                     if(!is.matrix(data)) data <- as.matrix(data)  
@@ -100,7 +102,9 @@ function(y,x,data,z=NULL,n.obs=NULL,use="pairwise",std=TRUE,square=FALSE,main="R
       				 { beta <- solve(x.matrix,xy.matrix)       #solve the equation bY~aX
        					 beta <- as.matrix(beta) 
        					 }
+       if(raw) {if(numy > 1) { intercept <- means[y] - colSums(means[x] * beta[x,y ])} else {intercept <- means[y] - sum(means[x] * beta[x,y ])} } else {intercept <- NA}
 
+      #  } 
 
        	yhat <- t(xy.matrix) %*% solve(x.matrix) %*% (xy.matrix)
        	resid <- y.matrix - yhat
@@ -164,14 +168,26 @@ function(y,x,data,z=NULL,n.obs=NULL,use="pairwise",std=TRUE,square=FALSE,main="R
      	                    # uniq <- (1-smc(x.matrix,covar=!std))
      	                     uniq <- (1-smc(x.matrix))
      	                     se.beta <- list() 
+     	                     ci.lower <- list()
+     	                     ci.upper <- list()
      	                     for (i in 1:length(y)) {
      	                     df <- n.obs-k-1
      	                     se.beta[[i]] <- (sqrt((1-R2[i])/(df))*sqrt(1/uniq))}    
      	                     se <- matrix(unlist(se.beta),ncol=length(y))
      	                     colnames(se) <- colnames(beta)
      	                     rownames(se) <- rownames(beta)
-     	                     
+     	                    
      	                     se <- t(t(se) * sqrt(diag(C)[y]))/sqrt(diag(xc.matrix))
+     	                     for(i in 1:length(y))  {ci.lower[[i]] <-  beta[,i] - qt(1-alpha/2,df)*se[,i]
+     	                                             ci.upper[[i]] <- beta[,i] + qt(1-alpha/2,df)*se[,i]}
+     	                     ci.lower <- matrix(unlist(ci.lower),ncol=length(y))
+     	                     ci.upper <- matrix(unlist(ci.upper),ncol=length(y))
+     	               
+     	                       colnames( ci.lower) <-  colnames( ci.upper) <- colnames( beta)
+     	                     rownames( ci.lower)<- rownames( ci.upper) <- rownames(beta)
+
+     	                     confid.beta <- cbind(ci.lower,ci.upper)
+     	                    
      	                     tvalue <- beta/se
      	               # prob <- 2*(1- pt(abs(tvalue),df))
      	                prob <- -2 *  expm1(pt(abs(tvalue),df,log.p=TRUE))  
@@ -211,8 +227,8 @@ function(y,x,data,z=NULL,n.obs=NULL,use="pairwise",std=TRUE,square=FALSE,main="R
         
        # coeff <- data.frame(beta=beta,se = se,t=tvalue, Probabilty=prob)
        # colnames(coeff) <- c("Estimate", "Std. Error" ,"t value", "Pr(>|t|)")
-     	if(is.null(n.obs)) {set.cor <- list(beta=beta,R=sqrt(R2),R2=R2,Rset=Rset,T=T,cancor = cc, cancor2=cc2,raw=raw,residual=resid,ruw=ruw,Ruw=Ruw,x.matrix=x.matrix,y.matrix=y.matrix,VIF=VIF,Call = cl)} else {
-     	              set.cor <- list(beta=beta,se=se,t=tvalue,Probability = prob,R=sqrt(R2),R2=R2,shrunkenR2 = shrunkenR2,seR2 = SE,F=F,probF=pF,df=c(k,df),Rset=Rset,Rset.shrunk=R2set.shrunk,Rset.F=Rset.F,Rsetu=u,Rsetv=df.v,T=T,cancor=cc,cancor2 = cc2,Chisq = Chisq,raw=raw,residual=resid,ruw=ruw,Ruw=Ruw,x.matrix=x.matrix,y.matrix=y.matrix,VIF=VIF,data=data,Call = cl)}
+     	if(is.null(n.obs)) {set.cor <- list(beta=beta,R=sqrt(R2),R2=R2,Rset=Rset,T=T,intercept=intercept,cancor = cc, cancor2=cc2,raw=raw,residual=resid,ruw=ruw,Ruw=Ruw,x.matrix=x.matrix,y.matrix=y.matrix,VIF=VIF,Call = cl)} else {
+     	              set.cor <- list(beta=beta,se=se,t=tvalue,Probability = prob,intercept=intercept,ci=confid.beta,R=sqrt(R2),R2=R2,shrunkenR2 = shrunkenR2,seR2 = SE,F=F,probF=pF,df=c(k,df),Rset=Rset,Rset.shrunk=R2set.shrunk,Rset.F=Rset.F,Rsetu=u,Rsetv=df.v,T=T,cancor=cc,cancor2 = cc2,Chisq = Chisq,raw=raw,residual=resid,ruw=ruw,Ruw=Ruw,x.matrix=x.matrix,y.matrix=y.matrix,VIF=VIF,data=data,Call = cl)}
      	class(set.cor) <- c("psych","setCor")
      	if(plot) setCor.diagram(set.cor,main=main,show=show)
      	return(set.cor)
@@ -227,14 +243,15 @@ function(y,x,data,z=NULL,n.obs=NULL,use="pairwise",std=TRUE,square=FALSE,main="R
 #modified February 19, 2015 to just find the covariances of the data that are used in the regression
 #this gets around the problem that some users have large data sets, but only want a few variables in the regression
 #corrected February 17, 2018 to correctly find the unweighted correlations
-
+#mdified Sept 22, 2018 to allow cex and l.cex to be set
 
 #mdified November, 2017 to allow an override of which way to draw the arrows  
-setCor.diagram <- function(sc,main="Regression model",digits=2,show=FALSE,...) { 
-
+setCor.diagram <- function(sc,main="Regression model",digits=2,show=FALSE,cex=1,l.cex=1,...) { 
+if(missing(l.cex)) l.cex <- cex  
 beta <- round(sc$beta,digits)
 x.matrix <- round(sc$x.matrix,digits)
 y.matrix <- round(sc$y.matrix,digits)
+y.resid <- round(sc$resid,digits)
 x.names <- rownames(sc$beta)
 y.names <- colnames(sc$beta)
 nx <- length(x.names)
@@ -248,23 +265,24 @@ y <- list()
 x.scale <- top/(nx+1)
 y.scale <- top/(ny+1)
 plot(NA,xlim=xlim,ylim=ylim,main=main,axes=FALSE,xlab="",ylab="")
-for(i in 1:nx) {x[[i]] <- dia.rect(3,top-i*x.scale,x.names[i]) }
+for(i in 1:nx) {x[[i]] <- dia.rect(3,top-i*x.scale,x.names[i],cex=cex,...) }
  
-for (j in 1:ny) {y[[j]] <- dia.rect(7,top-j*y.scale,y.names[j]) }
+for (j in 1:ny) {y[[j]] <- dia.rect(7,top-j*y.scale,y.names[j],cex=cex,...) }
 for(i in 1:nx) {
   for (j in 1:ny) {
-   dia.arrow(x[[i]]$right,y[[j]]$left,labels = beta[i,j],adj=4-j)
+   dia.arrow(x[[i]]$right,y[[j]]$left,labels = beta[i,j],adj=4-j,cex=l.cex,...)
    }
 } 
 if(nx >1) {
   for (i in 2:nx) {
-  for (k in 1:(i-1)) {dia.curved.arrow(x[[i]]$left,x[[k]]$left,x.matrix[i,k],scale=-(abs(i-k)),both=TRUE,dir="u")} 
+  for (k in 1:(i-1)) {dia.curved.arrow(x[[i]]$left,x[[k]]$left,x.matrix[i,k],scale=-(abs(i-k)),both=TRUE,dir="u",cex = l.cex,...)}
+                      #dia.curve(x[[i]]$left,x[[k]]$left,x.matrix[i,k],scale=-(abs(i-k)))  } 
   } }
   
   if(ny>1) {for (i in 2:ny) {
-  for (k in 1:(i-1)) {dia.curved.arrow(y[[i]]$right,y[[k]]$right,y.matrix[i,k],scale=(abs(i-k)),dir="u")} 
+  for (k in 1:(i-1)) {dia.curved.arrow(y[[i]]$right,y[[k]]$right,y.resid[i,k],scale=(abs(i-k)),dir="u",cex=l.cex, ...)} 
   }}
-  for(i in 1:ny) {dia.self(y[[i]],side=3,scale=.2) }
+  for(i in 1:ny) {dia.self(y[[i]],side=3,scale=.2,... )}
  if(show) {text((10-nx/3)/2,0,paste("Unweighted matrix correlation  = ",round(sc$Ruw,digits)))}
 }
 		 
@@ -303,9 +321,10 @@ print.psych.setCor <- function(x,digits=2) {
               print(x$Call)
             if(x$raw) {cat("\nMultiple Regression from raw data \n")} else {
             cat("\nMultiple Regression from matrix input \n")}
-          for(i in 1:NCOL(x$beta)) {cat("\n DV = ",colnames(x$beta)[i], "\n")
-          if(!is.null(x$se)) {result.df <- data.frame( round(x$beta[,i],digits),round(x$se[,i],digits),round(x$t[,i],digits),signif(x$Probability[,i],digits),round(x$VIF,digits))
-              colnames(result.df) <- c("slope","se", "t", "p", "VIF")        
+          for(i in 1:NCOL(x$beta)) {cat("\n DV = ",colnames(x$beta)[i])
+          if(!is.na(x$intercept[i])) {cat(' intercept = ',round(x$intercept[i],digits=digits),"\n")}
+          if(!is.null(x$se)) {result.df <- data.frame( round(x$beta[,i],digits),round(x$se[,i],digits),round(x$t[,i],digits),signif(x$Probability[,i],digits),round(x$ci[,i],digits), round(x$ci[,(i+2)],digits),round(x$VIF,digits))
+              colnames(result.df) <- c("slope","se", "t", "p","lower.ci","upper.ci",  "VIF")        
               print(result.df)      
               result.df <- data.frame(R = round(x$R[i],digits), R2 = round(x$R2[i],digits), Ruw = round(x$ruw[i],digits),R2uw =  round( x$ruw[i]^2,digits), round(x$shrunkenR2[i],digits),round(x$seR2[i],digits), round(x$F[i],digits),x$df[1],x$df[2], signif(x$probF[i],digits+1))
               colnames(result.df) <- c("R","R2", "Ruw", "R2uw","Shrunken R2", "SE of R2", "overall F","df1","df2","p")
